# -*- coding: utf-8 -*-
"""
app.main.views
~~~~~~~~~~~~~~

This module implements the main blueprint.

:copyright: (c) 2017 European Spallation Source ERIC
:license: BSD 2-Clause, see LICENSE for more details.

"""
import os
from flask import Blueprint, render_template, jsonify, request, current_app
from flask_login import login_required
from .. import utils

bp = Blueprint('main', __name__)


# Declare custom error handlers for all views
@bp.app_errorhandler(404)
def not_found_error(error):
    return render_template('404.html'), 404


@bp.app_errorhandler(500)
def internal_error(error):
    return render_template('500.html'), 500


@bp.app_errorhandler(utils.CSEntryError)
def handle_csentry_error(error):
    response = jsonify(error.to_dict())
    response.status_code = error.status_code
    return response


@bp.app_url_defaults
def modified_static_file(endpoint, values):
    """Add a last modified query parameter to static resource

    Force the browser to invalidate the cache and reload resources
    when files have changed

    Inspired from http://flask.pocoo.org/snippets/40/ and
    https://gist.github.com/Ostrovski/f16779933ceee3a9d181
    """
    if endpoint == 'static':
        filename = values.get('filename')
        if filename:
            # The same static folder is used for all blueprints
            file_path = os.path.join(current_app.static_folder, filename)
            values['m'] = int(os.stat(file_path).st_mtime)


@bp.route('/')
@login_required
def index():
    return render_template('index.html')
